==> nextcloud-27.1.1p0.tgz: nextcloud/apps/password_policy/l10n/pt_BR.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "A senha expirou. Use \"esqueceu a senha\" para redefini-la",
    "Password must not have been used recently before." : "A senha não pode ter sido usada recentemente.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "A senha está entre as 1.000.000 mais comuns. Por favor, torne-a única.",
    "Password is present in compromised password list. Please choose a different password." : "A senha está presente na lista de senhas comprometidas. Escolha uma senha diferente.",
    "Password needs to be at least %s characters long." : "A senha precisa ter no mínimo %s caracteres.",
    "Password needs to contain at least one numeric character." : "A senha precisa conter pelo menos um caractere numérico.",
    "Password needs to contain at least one special character." : "A senha precisa conter pelo menos um caractere especial.",
    "Password needs to contain at least one lower and one upper case character." : "A senha precisa conter pelo menos um caractere minúsculo e um maiúsculo.",
    "Password policy" : "Política de senhas",
    "Allows admins to configure a password policy" : "Permite aos administradores configurarem uma política de senha",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permitir que o administrador defina determinadas pré-condições para a senha, por exemplo,  um tamanho mínimo",
    "Minimum password length" : "Tamanho mínimo para senhas",
    "User password history" : "Histórico de senhas do usuário",
    "Number of days until user password expires" : "Número de dias até a expiração da senha do usuário",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Número de tentativas de autenticação antes que a conta do usuário seja bloqueada (0 para sem limite)",
    "Forbid common passwords" : "Proibir senhas comuns",
    "Enforce upper and lower case characters" : "Forçar caracteres maiúsculos e minúsculos",
    "Enforce numeric characters" : "Forçar aplicar caracteres numéricos",
    "Enforce special characters" : "Forçar aplicar caracteres especiais",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Verificar a senha com relação à lista de senhas violadas de haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Essa verificação cria um hash da senha e envia os primeiros 5 caracteres desse hash para a API haveibeenpwned.com para recuperar uma lista de todos os hashes que começam com eles. Em seguida, ele verifica com o servidor Nextcloud se o hash da senha está no conjunto de resultados.",
    "Unknown error" : "Erro desconhecido",
    "Minimal length has to be a non negative number" : "O tamanho mínimo não pode ser um número negativo",
    "History size has to be a non negative number" : "O tamanho do histórico não pode ser um número negativo",
    "Expiration days have to be a non negative number" : "Dias para expiração não pode ser um número negativo",
    "Maximum login attempts have to be a non negative number" : "O máximo de tentativas de login não pode ser um número negativo",
    "Settings saved" : "Configurações salvas",
    "Error while saving settings" : "Error while saving settings",
    "Saved" : "Salva",
    "Error while saving" : "Erro ao salvar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-28.0.9.tgz: nextcloud/apps/password_policy/l10n/pt_BR.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "A senha expirou. Use \"esqueceu a senha\" para redefini-la",
    "Password must not have been used recently before." : "A senha não pode ter sido usada recentemente.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "A senha está entre as 1.000.000 mais comuns. Por favor, torne-a única.",
    "Password is present in compromised password list. Please choose a different password." : "A senha está presente na lista de senhas comprometidas. Escolha uma senha diferente.",
    "Password needs to be at least %s characters long." : "A senha precisa ter no mínimo %s caracteres.",
    "Password needs to contain at least one numeric character." : "A senha precisa conter pelo menos um caractere numérico.",
    "Password needs to contain at least one special character." : "A senha precisa conter pelo menos um caractere especial.",
    "Password needs to contain at least one lower and one upper case character." : "A senha precisa conter pelo menos um caractere minúsculo e um maiúsculo.",
    "Password policy" : "Política de senhas",
    "Allows admins to configure a password policy" : "Permite aos administradores configurarem uma política de senha",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permitir que o administrador defina determinadas pré-condições para a senha, por exemplo,  um tamanho mínimo",
    "Minimum password length" : "Tamanho mínimo para senhas",
    "User password history" : "Histórico de senhas do usuário",
    "Number of days until user password expires" : "Número de dias até a expiração da senha do usuário",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Número de tentativas de login antes que a conta do usuário seja desativada até que uma ação manual seja executada. (0 para sem limite)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Observe que esta opção destina-se a proteger contas atacadas. As contas desativadas devem ser reativadas manualmente pela administração. Os invasores que tentarem adivinhar as senhas das contas terão seus endereços IP bloqueados pela proteção de força bruta independente desta configuração.",
    "Forbid common passwords" : "Proibir senhas comuns",
    "Enforce upper and lower case characters" : "Forçar caracteres maiúsculos e minúsculos",
    "Enforce numeric characters" : "Forçar aplicar caracteres numéricos",
    "Enforce special characters" : "Forçar aplicar caracteres especiais",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Verificar a senha com relação à lista de senhas violadas de haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Essa verificação cria um hash da senha e envia os primeiros 5 caracteres desse hash para a API haveibeenpwned.com para recuperar uma lista de todos os hashes que começam com eles. Em seguida, ele verifica com o servidor Nextcloud se o hash da senha está no conjunto de resultados.",
    "Unknown error" : "Erro desconhecido",
    "Minimal length has to be a non negative number" : "O tamanho mínimo não pode ser um número negativo",
    "History size has to be a non negative number" : "O tamanho do histórico não pode ser um número negativo",
    "Expiration days have to be a non negative number" : "Dias para expiração não pode ser um número negativo",
    "Maximum login attempts have to be a non negative number" : "O máximo de tentativas de login não pode ser um número negativo",
    "Settings saved" : "Configurações salvas",
    "Error while saving settings" : "Error while saving settings",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Observe que esta opção se destina a proteger contas atacadas. As contas desativadas devem ser reativadas manualmente pela administração. Os invasores que tentarem adivinhar as senhas das contas terão seus endereços IP bloqueados pela proteção de força bruta independente desta configuração."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
